<?php


function mybook_setup() {


	load_theme_textdomain( 'mybook', get_template_directory() . '/languages' );
	
	add_editor_style('css/editor-style.css');
	
	add_theme_support( 'automatic-feed-links' );
	
	register_nav_menu( 'primary', __( 'Primary Menu', 'mybook' ) );

	add_theme_support( 'custom-background', array(

		'default-color' => 'e9e9e9',

	) );


	add_theme_support( 'post-thumbnails' );

	set_post_thumbnail_size( 400 ); // Unlimited height, soft crop

	add_image_size( 'product_archive', 160 ); 
	add_image_size( 'slider_image', 960 ); 
	add_image_size( 'homepage_blog', 400 ); 

	require( get_template_directory() . '/inc/slides.php' );
	require( get_template_directory() . '/inc/products.php' );

	require_once(TEMPLATEPATH . '/admin/admin-functions.php');
	require_once(TEMPLATEPATH . '/admin/admin-interface.php');
	require_once(TEMPLATEPATH . '/admin/theme-settings.php');
	
}

add_action( 'after_setup_theme', 'mybook_setup' );


/**

 * Enqueue scripts and styles for front-end.

*/

function mybook_scripts_styles() {

	global $wp_styles;



	/*

	 * Adds JavaScript to pages with the comment form to support

	 * sites with threaded comments (when in use).

	 */

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )

		wp_enqueue_script( 'comment-reply' );

	wp_enqueue_script('jquery');

	// Adds JavaScript for handling the navigation menu hide-and-show behavior.

	wp_enqueue_script( 'mybook-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '1.0', true );



	// Loads our main stylesheet.

	wp_enqueue_style( 'mybook-style', get_stylesheet_uri() );



	// Loads the Internet Explorer specific stylesheet.

	wp_enqueue_style( 'mybook-ie', get_template_directory_uri() . '/css/ie.css', array( 'mybook-style' ), '20121010' );

	$wp_styles->add_data( 'mybook-ie', 'conditional', 'lt IE 9' );

}

add_action( 'wp_enqueue_scripts', 'mybook_scripts_styles' );



/**

 * Filter the page title.

*/

function mybook_wp_title( $title, $sep ) {

	global $paged, $page;



	if ( is_feed() )

		return $title;



	// Add the site name.

	$title .= get_bloginfo( 'name' );



	// Add the site description for the home/front page.

	$site_description = get_bloginfo( 'description', 'display' );

	if ( $site_description && ( is_home() || is_front_page() ) )
	if ( $site_description && ( is_home() || is_front_page() ) )

		$title = "$title $sep $site_description";



	// Add a page number if necessary.

	if ( $paged >= 2 || $page >= 2 )

		$title = "$title $sep " . sprintf( __( 'Page %s', 'mybook' ), max( $paged, $page ) );



	return $title;

}

add_filter( 'wp_title', 'mybook_wp_title', 10, 2 );



/**

 * Filter the page menu arguments.

 */

function mybook_page_menu_args( $args ) {

	if ( ! isset( $args['show_home'] ) )

		$args['show_home'] = true;

	return $args;

}

add_filter( 'wp_page_menu_args', 'mybook_page_menu_args' );



/**

 * Register sidebars.

*/

function mybook_widgets_init() {



	register_sidebar( array(

		'name' => __( 'Primary Sidebar', 'mybook' ),

		'id' => 'sidebar-1',

		'description' => __( 'Appears on posts and pages.', 'mybook' ),

		'before_widget' => '<aside id="%1$s" class="widget %2$s">',

		'after_widget' => '</aside>',

		'before_title' => '<h3 class="widget-title">',

		'after_title' => '</h3>',

	) );	register_sidebar( array(		'name' => __( 'Left Footer', 'mybook' ),		'id' => 'sidebar-2',		'description' => __( 'Appears on posts and pages at Footer.', 'mybook' ),		'before_widget' => '<div id="%1$s" class="widget %2$s">',		'after_widget' => '</div>',		'before_title' => '<h3 class="widget-title">',		'after_title' => '</h3>',	) );	register_sidebar( array(		'name' => __( 'Middle Footer', 'mybook' ),		'id' => 'sidebar-3',		'description' => __( 'Appears on posts and pages. on Footer', 'mybook' ),		'before_widget' => '<div id="%1$s" class="widget %2$s">',		'after_widget' => '</div>',		'before_title' => '<h3 class="widget-title">',		'after_title' => '</h3>',	) );	register_sidebar( array(		'name' => __( 'Right Footer', 'mybook' ),		'id' => 'sidebar-4',		'description' => __( 'Appears on posts and pages on Footer.', 'mybook' ),		'before_widget' => '<div id="%1$s" class="widget %2$s">',		'after_widget' => '</div>',		'before_title' => '<h3 class="widget-title">',		'after_title' => '</h3>',	) );

}

add_action( 'widgets_init', 'mybook_widgets_init' );



if ( ! function_exists( 'mybook_content_nav' ) ) :

/**

 * Displays navigation to next/previous pages when applicable.

*/

function mybook_content_nav( $html_id ) {

	global $wp_query;

	$html_id = esc_attr( $html_id );

	if ( $wp_query->max_num_pages > 1 ) : ?>

		<nav id="<?php echo $html_id; ?>" class="navigation" role="navigation">

			<h3 class="assistive-text"><?php _e( 'Post navigation', 'mybook' ); ?></h3>

			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'mybook' ) ); ?></div>

			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'mybook' ) ); ?></div>

		</nav><!-- #<?php echo $html_id; ?> .navigation -->

	<?php endif;

}

endif;



if ( ! function_exists( 'mybook_comment' ) ) :

/**

 * Template for comments and pingbacks.

*/

function mybook_comment( $comment, $args, $depth ) {

	$GLOBALS['comment'] = $comment;

	switch ( $comment->comment_type ) :

		case 'pingback' :

		case 'trackback' :

		// Display trackbacks differently than normal comments.

	?>

	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">

		<p><?php _e( 'Pingback:', 'mybook' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'mybook' ), '<span class="edit-link">', '</span>' ); ?></p>

	<?php

			break;

		default :

		// Proceed with normal comments.

		global $post;

	?>

	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">

		<article id="comment-<?php comment_ID(); ?>" class="comment">

			<header class="comment-meta comment-author vcard">

				<?php

					echo get_avatar( $comment, 44 );

					printf( '<cite><b class="fn">%1$s</b> %2$s</cite>',

						get_comment_author_link(),

						// If current post author is also comment author, make it known visually.

						( $comment->user_id === $post->post_author ) ? '<span>' . __( 'Post author', 'mybook' ) . '</span>' : ''

					);

					printf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',

						esc_url( get_comment_link( $comment->comment_ID ) ),

						get_comment_time( 'c' ),

						/* translators: 1: date, 2: time */

						sprintf( __( '%1$s at %2$s', 'mybook' ), get_comment_date(), get_comment_time() )

					);

				?>

			</header><!-- .comment-meta -->



			<?php if ( '0' == $comment->comment_approved ) : ?>

				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'mybook' ); ?></p>

			<?php endif; ?>



			<section class="comment-content comment">

				<?php comment_text(); ?>

				<?php edit_comment_link( __( 'Edit', 'mybook' ), '<p class="edit-link">', '</p>' ); ?>

			</section><!-- .comment-content -->



			<div class="reply">

				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'mybook' ), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>

			</div><!-- .reply -->

		</article><!-- #comment-## -->

	<?php

		break;

	endswitch; // end comment_type check

}

endif;



if ( ! function_exists( 'mybook_entry_meta' ) ) :

/**

 * Set up post entry meta.

*/

function mybook_entry_meta() {

		$categories_list = get_the_category_list( __( ', ', 'mybook' ) );

		$num_comments = get_comments_number();
		
		$comments_link = get_comments_link( $post_ID ); 

		$author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',

		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),

		esc_attr( sprintf( __( 'View all posts by %s', 'mybook' ), get_the_author() ) ),

		get_the_author()

	);


	if ( $categories_list ) {

		$utility_text = __( '<span class="by-author"> by %1$s</span> in %2$s <span class="comment-count"><a href="'.$comments_link.'">%3$s Comments</a></span>', 'mybook' );

	} else {

		$utility_text = __( '<span class="by-author"> by %1$s</span> <span class="comment-count"><a href="'.$comments_link.'">%3$s Comments</a></span>', 'mybook' );

	}



	printf(

		$utility_text,

		$author,

		$categories_list,

		$num_comments

	);

}

endif;



/**

 * Extend the default WordPress body classes.

 */

function mybook_body_class( $classes ) {

	$background_color = get_background_color();

	$background_image = get_background_image();



	if ( ! is_active_sidebar( 'sidebar-1' ) || is_page_template( 'page-templates/full-width.php' ) )

		$classes[] = 'full-width';



	if ( is_page_template( 'page-templates/front-page.php' ) ) {

		$classes[] = 'template-front-page';

		if ( has_post_thumbnail() )

			$classes[] = 'has-post-thumbnail';
	}



	if ( empty( $background_image ) ) {

		if ( empty( $background_color ) )

			$classes[] = 'custom-background-empty';

		elseif ( in_array( $background_color, array( 'fff', 'ffffff' ) ) )

			$classes[] = 'custom-background-white';

	}


	if ( ! is_multi_author() )

		$classes[] = 'single-author';



	return $classes;

}

add_filter( 'body_class', 'mybook_body_class' );



function excerpt_read_more_link($output) {

	global $post;

	return $output . '<a class="read-more" href="'. get_permalink($post->ID) . '">Continue reading &rarr;</a>';

}

add_filter('the_excerpt', 'excerpt_read_more_link');




function new_excerpt_more( $more ) {

	return '&hellip;';

}

add_filter('excerpt_more', 'new_excerpt_more');



function custom_excerpt_lentth( $lentth ) {

	return 20;

}

add_filter( 'excerpt_lentth', 'custom_excerpt_lentth', 999 );

	
function review($atts, $content = null) {
	extract(shortcode_atts(array(
	"stars" => '5'
	), $atts));
	
return '<div class="review"><img src="'.get_template_directory_uri().'/images/stars'.$stars.'.jpg"/><p>'.$content.'</p></div>';

}

add_shortcode("review", "review");  




function free_tag_id() {
    global $wpdb;
    $tag_ID = $wpdb->get_var("SELECT * FROM ".$wpdb->terms." WHERE  `name` =  'free'");

    return $tag_ID;
}
